API Glossary
============

Contents:

.. toctree::
   :maxdepth: 2

.. automodule:: purestorage

.. autoclass:: FlashArray
    :members:

.. autoclass:: PureError

.. autoclass:: PureHTTPError

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

